==> zio-aws-networkmanager_3-5.17.158.3-sources.jar: zio/aws/networkmanager/model/GetSiteToSiteVpnAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetSiteToSiteVpnAttachmentResponse(
    siteToSiteVpnAttachment: Option[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse = {
    import GetSiteToSiteVpnAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
      .builder()
      .optionallyWith(
        siteToSiteVpnAttachment.map(value => value.buildAwsValue())
      )(_.siteToSiteVpnAttachment)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
      .wrap(buildAwsValue())
}
object GetSiteToSiteVpnAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse =
      zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse(
        siteToSiteVpnAttachment.map(value => value.asEditable)
      )
    def siteToSiteVpnAttachment
        : Option[zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly]
    def getSiteToSiteVpnAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = AwsError.unwrapOptionField(
      "siteToSiteVpnAttachment",
      siteToSiteVpnAttachment
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ) extends zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly {
    override val siteToSiteVpnAttachment: Option[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = scala
      .Option(impl.siteToSiteVpnAttachment())
      .map(value =>
        zio.aws.networkmanager.model.SiteToSiteVpnAttachment.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ): zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-6.20.78.2-sources.jar: zio/aws/networkmanager/model/GetSiteToSiteVpnAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetSiteToSiteVpnAttachmentResponse(
    siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse = {
    import GetSiteToSiteVpnAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
      .builder()
      .optionallyWith(
        siteToSiteVpnAttachment.map(value => value.buildAwsValue())
      )(_.siteToSiteVpnAttachment)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
      .wrap(buildAwsValue())
}
object GetSiteToSiteVpnAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse =
      zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse(
        siteToSiteVpnAttachment.map(value => value.asEditable)
      )
    def siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ]
    def getSiteToSiteVpnAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = AwsError.unwrapOptionField(
      "siteToSiteVpnAttachment",
      siteToSiteVpnAttachment
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ) extends zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly {
    override val siteToSiteVpnAttachment: Optional[
      zio.aws.networkmanager.model.SiteToSiteVpnAttachment.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.siteToSiteVpnAttachment())
      .map(value =>
        zio.aws.networkmanager.model.SiteToSiteVpnAttachment.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetSiteToSiteVpnAttachmentResponse
  ): zio.aws.networkmanager.model.GetSiteToSiteVpnAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}
